fisx: Member List

fisx

fisx::XRF Member List

This is the complete list of members for fisx::XRF, including all inherited members.

addCollimator() (defined in fisx::XRF) | fisx::XRF |
getAlphaIn() const (defined in fisx::XRF) | fisx::XRF | inline
getAlphaOut() const (defined in fisx::XRF) | fisx::XRF | inline
getAttenuators() const | fisx::XRF | inline
getBeam() const | fisx::XRF | inline
getBeamFilters() const | fisx::XRF | inline
getConfiguration() const | fisx::XRF |
getDetector() const | fisx::XRF | inline
getEnergyThreshold(const std::string &elementName, const std::string &family, const Elements &elementsLibrary) const (defined in fisx::XRF) | fisx::XRF |
getExpectedPrimaryEmission(const std::vector< std::string > &elementList, const Elements &elements) | fisx::XRF |
getGeometricEfficiency(const int &layerIndex=0) const | fisx::XRF |
getMultilayerFluorescence(const std::string &element, const Elements &elementsLibrary, const int &sampleLayerIndex=0, const std::string &lineFamily="", const int &secondary=0, const int &useGeometricEfficiency=1, const int &useMassFractions=0, const double &secondaryCalculationLimit=0.0) | fisx::XRF |
getMultilayerFluorescence(const std::vector< std::string > &elementFamilyLayer, const Elements &elementsLibrary, const int &secondary=0, const int &useGeometricEfficiency=1, const int &useMassFractions=0, const double &secondaryCalculationLimit=0.0) | fisx::XRF |
getMultilayerFluorescence(const std::vector< std::string > &elementList, const Elements &elementsLibrary, const std::vector< int > &layerList, const std::vector< std::string > &familyList, const int &secondary=0, const int &useGeometricEfficiency=1, const int &useMassFractions=0, const double &secondaryCalculationLimit=0.0) (defined in fisx::XRF) | fisx::XRF |
getReferenceLayer() const (defined in fisx::XRF) | fisx::XRF | inline
getSample() const | fisx::XRF | inline
getScatteringAngle() const (defined in fisx::XRF) | fisx::XRF | inline
getUserAttenuators() const | fisx::XRF | inline
getUserBeamFilters() const | fisx::XRF | inline
readConfigurationFromFile(const std::string &fileName) | fisx::XRF |
setAttenuators(const std::vector< Layer > &attenuators) | fisx::XRF |
setBeam(const Beam &beam) | fisx::XRF |
setBeam(const std::vector< double > &energies, const std::vector< double > &weight, const std::vector< int > &characteristic=std::vector< int >(), const std::vector< double > &divergency=std::vector< double >()) | fisx::XRF |
setBeam(const double &energy, const double &divergency=0.0) | fisx::XRF |
setBeamFilters(const std::vector< Layer > &filters) | fisx::XRF |
setCollimators() | fisx::XRF |
setConfiguration(const XRFConfig &configuration) | fisx::XRF |
setDetector(const Detector &detector) | fisx::XRF |
setGeometry(const double &alphaIn, const double &alphaOut, const double &scatteringAngle=-90.) | fisx::XRF |
setRefenceLayer(const std::string &name) (defined in fisx::XRF) | fisx::XRF |
setReferenceLayer(const int &index) | fisx::XRF |
setSample(const std::vector< Layer > &layers, const int &referenceLayer=0) | fisx::XRF |
setSample(const std::string &name, const double &density=1.0, const double &thickness=1.0) | fisx::XRF |
setSample(const Layer &layer) | fisx::XRF |
setUserAttenuators(const std::vector< TransmissionTable > &userAttenuators) | fisx::XRF |
setUserBeamFilters(const std::vector< TransmissionTable > &userFilters) | fisx::XRF |
XRF() | fisx::XRF |
XRF(const std::string &configurationFile) | fisx::XRF |